@@ -28,4 +28,8 @@ class GroupMembershipAdmin(admin.ModelAdmin):
     )
 
 admin.site.register(Group, GroupAdmin)
-#admin.site.register(GroupMembership, GroupMembershipAdmin)
\ No newline at end of file
+#admin.site.register(GroupMembership, GroupMembershipAdmin)
+
+from django.contrib.auth.models import Group as AuthGroup
+# unregister AuthGroup
+admin.site.unregister(AuthGroup)
\ No newline at end of file
